@@ -1,4 +1,6 @@
 from __future__ import annotations
+
+from compositefk.fields import CompositeForeignKey
 from django.db import models
 from django.utils import timezone
 import time
@@ -13,7 +15,7 @@ class InteligerQuerySet(models.QuerySet):
 
     def desabilitar(self, request_=None):
         usuario = request_.user.id if request_ is not None else None
-        qs = self.update(status=False, usr_delete_id=usuario, dat_delete=timezone.now())
+        qs = self.update(status=False, usr_delete=usuario, dat_delete=timezone.now())
         return qs
 
 
@@ -50,9 +52,30 @@ class DatLog(models.Model):
 
 
 class UsrLog(models.Model):
-    usr_insercao = models.ForeignKey('usr.Profile', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr_insercao')
-    usr_edicao = models.ForeignKey('usr.Profile', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr_edicao')
-    usr_delete = models.ForeignKey('usr.Profile', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr_delete')
+    usr_insercao = models.IntegerField(null=True)
+    usr_edicao = models.IntegerField(null=True)
+    usr_delete = models.IntegerField(null=True)
+    # trocar por inteiro
+    origem_insercao_codigo = models.CharField(null=True, max_length=200)
+    origem_insercao_tipo = models.CharField(null=True, max_length=200, default='USR.ORIGEM')
+    origem_insercao = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem_insercao', to_fields={
+        "codigo": "origem_insercao_codigo",
+        "tipo": "origem_insercao_tipo"
+    })
+
+    origem_edicao_codigo = models.CharField(null=True, max_length=200)
+    origem_edicao_tipo = models.CharField(null=True, max_length=200, default='USR.ORIGEM')
+    origem_edicao = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem_edicao', to_fields={
+        "codigo": "origem_edicao_codigo",
+        "tipo": "origem_edicao_tipo"
+    })
+
+    origem_delete_codigo = models.CharField(null=True, max_length=200)
+    origem_delete_tipo = models.CharField(null=True, max_length=200, default='USR.ORIGEM')
+    origem_delete = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem_delete', to_fields={
+        "codigo": "origem_delete_codigo",
+        "tipo": "origem_delete_tipo"
+    })
 
     class Meta:
         managed = False
@@ -66,17 +89,17 @@ class Log(DatLog, UsrLog):
     status = models.BooleanField(null=True, default=True)
 
     class Meta:
-        managed = False
+        managed = True
         abstract = True
 
     def save(self, request_=None, *args, **kwargs):
         if request_ is not None:
             if self.pk is None:
-                self.usr_insercao_id = request_.user.id if request_ is not None else None
+                self.usr_insercao = request_.user.id if request_ is not None else None
                 self.dat_insercao = timezone.now()
                 self.status = True
             else:
-                self.usr_edicao_id = request_.user.id if request_ is not None else None
+                self.usr_edicao = request_.user.id if request_ is not None else None
                 self.dat_edicao = timezone.now()
         super(Log, self).save(*args, **kwargs)
 
@@ -87,6 +110,93 @@ class Log(DatLog, UsrLog):
         super(Log, self).save(*args, **kwargs)
 
 
+class EmpresaLog(models.Model):
+    empresa = models.ForeignKey('core.Empresa', on_delete=models.DO_NOTHING, null=True)
+
+    class Meta(Log.Meta):
+        abstract = True
+
+
+class ContatoLog(models.Model):
+    celular = models.CharField(max_length=50, null=True)
+    telefone = models.CharField(max_length=50, null=True)
+    email = models.EmailField(max_length=200, null=True)
+
+    class Meta(Log.Meta):
+        abstract = True
+
+
+class PessoaLog(ContatoLog):
+    nm_completo = models.CharField(max_length=200, null=True)
+    nm_primeiro = models.CharField(max_length=200, null=True)
+    nm_ultimo = models.CharField(max_length=200, null=True)
+
+    cpf = models.BigIntegerField(null=True)
+    cpf_form = models.CharField(max_length=20, unique=True)
+
+    rg = models.CharField(max_length=15, null=True)
+
+    dat_nasc = models.DateField(null=True)
+
+    nm_mae = models.CharField(max_length=200, null=True)
+    nm_pai = models.CharField(max_length=200, null=True)
+
+    sexo_codigo = models.CharField(null=True, max_length=200)
+    sexo_tipo = models.CharField(null=True, max_length=200, default='PESSOA.SEXO')
+    sexo = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_sexo', to_fields={
+        "codigo": "sexo_codigo",
+        "tipo": "sexo_tipo"
+    })
+
+    educacao_codigo = models.CharField(null=True, max_length=200)
+    educacao_tipo = models.CharField(null=True, max_length=200, default='PESSOA.EDUCACAO')
+    educacao = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_educacao', to_fields={
+        "codigo": "educacao_codigo",
+        "tipo": "educacao_tipo"
+    })
+
+    ocupacao_codigo = models.CharField(null=True, max_length=200)
+    ocupacao_tipo = models.CharField(null=True, max_length=200, default='PESSOA.OCUPACAO')
+    ocupacao = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_ocupacao', to_fields={
+        "codigo": "ocupacao_codigo",
+        "tipo": "ocupacao_tipo"
+    })
+
+    estado_civil_codigo = models.CharField(null=True, max_length=200)
+    estado_civil_tipo = models.CharField(null=True, max_length=200, default='PESSOA.ESTADO_CIVIL')
+    estado_civil = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_estado_civil', to_fields={
+        "codigo": "estado_civil_codigo",
+        "tipo": "estado_civil_tipo"
+    })
+
+    class Meta(Log.Meta):
+        abstract = True
+
+
+class EnderecoLog(models.Model):
+    cep = models.CharField(max_length=10, null=True)
+    municipio = models.ForeignKey('core.Municipio', on_delete=models.DO_NOTHING, null=True)
+    bairro = models.CharField(max_length=100, null=True)
+    rua = models.CharField(max_length=100, null=True)
+    latitude_cep = models.CharField(max_length=200, null=True)
+    longitude_cep = models.CharField(max_length=200, null=True)
+
+    class Meta(Log.Meta):
+        abstract = True
+
+
+class EnderecoComplementoLog(models.Model):
+    cep = models.ForeignKey('core.Cep', null=True, on_delete=models.DO_NOTHING)
+    numero = models.CharField(max_length=30, null=True)
+    complemento = models.CharField(max_length=100, null=True)
+    ponto_referencia = models.CharField(max_length=100, null=True)
+    latitude = models.CharField(max_length=200, null=True)
+    longitude = models.CharField(max_length=200, null=True)
+
+    class Meta(Log.Meta):
+        abstract = True
+
+
 class Tipo(Log):
     codigo = models.IntegerField(null=True)
     tipo = models.CharField(max_length=200, null=True)
@@ -99,7 +209,6 @@ class Tipo(Log):
         unique_together = ('codigo', 'tipo')
 
 
-
 class Empresa(Log):
     nome = models.CharField(max_length=100, null=True)
 
@@ -108,48 +217,6 @@ class Empresa(Log):
         db_table = 'empresa'
 
 
-class EmpresaLog(models.Model):
-    empresa = models.ForeignKey(Empresa, on_delete=models.DO_NOTHING, null=True)
-
-    class Meta(Log.Meta):
-        abstract = True
-
-
-class Modulo(Log):
-    nome = models.SlugField(max_length=100, primary_key=True)
-    nm_descritivo = models.CharField(max_length=200, null=True)
-    modulo_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)
-
-    class Meta(Log.Meta):
-        abstract = False
-        db_table = 'modulo'
-
-
-class Versao(Log):
-    modulo = models.ForeignKey('core.Modulo', null=True, on_delete=models.DO_NOTHING)
-    responsavel = models.ForeignKey('usr.Profile', null=True, on_delete=models.DO_NOTHING)
-    dat_atualizacao = models.DateField(null=True)
-    codigo = models.CharField(max_length=100, null=True)
-    commit = models.CharField(max_length=50, null=True)
-    descricao = models.TextField(null=True)
-
-    class Meta(Log.Meta):
-        abstract = False
-        db_table = 'versao'
-
-
-
-class VersaoItem(Log):
-    versao = models.ForeignKey('core.Versao', null=True, on_delete=models.DO_NOTHING)
-    responsavel = models.ForeignKey('usr.Profile', null=True, on_delete=models.DO_NOTHING)
-    ordem = models.IntegerField(null=True)
-    descricao = models.TextField(null=True)
-
-    class Meta(Log.Meta):
-        abstract = False
-        db_table = 'versaoitem'
-
-
 class Erro(Log):
     nome = models.CharField(max_length=100)
     codigo = models.CharField(max_length=200, null=True)
@@ -160,26 +227,6 @@ class Erro(Log):
         db_table = 'erro'
 
 
-class UF(Log):
-    codigo = models.IntegerField(primary_key=True)
-    nome = models.CharField(max_length=200, null=True)
-    nm_abrev = models.CharField(max_length=2, null=True)
-
-    class Meta(Log.Meta):
-        abstract = False
-        db_table = 'uf'
-
-
-class Municipio(Log):
-    uf = models.ForeignKey('core.UF', on_delete=models.DO_NOTHING, null=True)
-    codigo = models.IntegerField(primary_key=True)
-    nome = models.CharField(max_length=200)
-
-    class Meta(Log.Meta):
-        abstract = False
-        db_table = 'municipio'
-
-
 class Data(Log):
     anomesdia = models.IntegerField(primary_key=True)
     anomes = models.IntegerField(null=True)
@@ -222,16 +269,40 @@ class Data(Log):
         db_table = 'data'
 
 
-class Endereco(Log):
-    cep = models.CharField(max_length=10, null=True)
-    municipio = models.ForeignKey('core.Municipio', on_delete=models.DO_NOTHING, null=True)
-    bairro = models.CharField(max_length=100, null=True)
-    rua = models.CharField(max_length=100, null=True)
-    numero = models.CharField(max_length=30, null=True)
-    complemento = models.CharField(max_length=100, null=True)
-    ponto_referencia = models.CharField(max_length=100, null=True)
-    latitude = models.CharField(max_length=200, null=True)
-    longitude = models.CharField(max_length=200, null=True)
+class Hora(Log):
+    descricao = models.CharField(max_length=200, null=True)
+    hora = models.IntegerField(null=True)
+    minuto = models.IntegerField(null=True)
+    hora_minuto = models.TimeField(null=True)
+    cd_hora_minuto = models.IntegerField(null=True)
 
     class Meta(Log.Meta):
-        abstract = True
+        abstract = False
+        db_table = 'hora'
+
+
+class UF(Log):
+    codigo = models.IntegerField(primary_key=True)
+    nome = models.CharField(max_length=200, null=True)
+    nm_abrev = models.CharField(max_length=2, null=True)
+
+    class Meta(Log.Meta):
+        abstract = False
+        db_table = 'uf'
+
+
+class Municipio(Log):
+    uf = models.ForeignKey('core.UF', on_delete=models.DO_NOTHING, null=True)
+    codigo = models.IntegerField(primary_key=True)
+    nome = models.CharField(max_length=200)
+
+    class Meta(Log.Meta):
+        abstract = False
+        db_table = 'municipio'
+
+
+class Cep(Log, EnderecoLog):
+
+    class Meta(Log.Meta):
+        abstract = False
+        db_table = 'cep'
\ No newline at end of file
